# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/api/servicecontrol/v1/quota_controller.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api.servicecontrol.v1 import metric_value_pb2 as google_dot_api_dot_servicecontrol_dot_v1_dot_metric__value__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/api/servicecontrol/v1/quota_controller.proto',
  package='google.api.servicecontrol.v1',
  syntax='proto3',
  serialized_options=b'\n com.google.api.servicecontrol.v1B\024QuotaControllerProtoP\001ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n3google/api/servicecontrol/v1/quota_controller.proto\x12\x1cgoogle.api.servicecontrol.v1\x1a\x1cgoogle/api/annotations.proto\x1a/google/api/servicecontrol/v1/metric_value.proto\"\x91\x01\n\x14\x41llocateQuotaRequest\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12H\n\x12\x61llocate_operation\x18\x02 \x01(\x0b\x32,.google.api.servicecontrol.v1.QuotaOperation\x12\x19\n\x11service_config_id\x18\x04 \x01(\t\"\xa5\x03\n\x0eQuotaOperation\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x13\n\x0bmethod_name\x18\x02 \x01(\t\x12\x13\n\x0b\x63onsumer_id\x18\x03 \x01(\t\x12H\n\x06labels\x18\x04 \x03(\x0b\x32\x38.google.api.servicecontrol.v1.QuotaOperation.LabelsEntry\x12\x43\n\rquota_metrics\x18\x05 \x03(\x0b\x32,.google.api.servicecontrol.v1.MetricValueSet\x12J\n\nquota_mode\x18\x06 \x01(\x0e\x32\x36.google.api.servicecontrol.v1.QuotaOperation.QuotaMode\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\tQuotaMode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x0f\n\x0b\x42\x45ST_EFFORT\x10\x02\x12\x0e\n\nCHECK_ONLY\x10\x03\"\xd0\x01\n\x15\x41llocateQuotaResponse\x12\x14\n\x0coperation_id\x18\x01 \x01(\t\x12\x41\n\x0f\x61llocate_errors\x18\x02 \x03(\x0b\x32(.google.api.servicecontrol.v1.QuotaError\x12\x43\n\rquota_metrics\x18\x03 \x03(\x0b\x32,.google.api.servicecontrol.v1.MetricValueSet\x12\x19\n\x11service_config_id\x18\x04 \x01(\t\"\xf8\x01\n\nQuotaError\x12;\n\x04\x63ode\x18\x01 \x01(\x0e\x32-.google.api.servicecontrol.v1.QuotaError.Code\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x86\x01\n\x04\x43ode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x16\n\x12\x42ILLING_NOT_ACTIVE\x10k\x12\x13\n\x0fPROJECT_DELETED\x10l\x12\x13\n\x0f\x41PI_KEY_INVALID\x10i\x12\x13\n\x0f\x41PI_KEY_EXPIRED\x10p2\xc2\x01\n\x0fQuotaController\x12\xae\x01\n\rAllocateQuota\x12\x32.google.api.servicecontrol.v1.AllocateQuotaRequest\x1a\x33.google.api.servicecontrol.v1.AllocateQuotaResponse\"4\x82\xd3\xe4\x93\x02.\")/v1/services/{service_name}:allocateQuota:\x01*B\x89\x01\n com.google.api.servicecontrol.v1B\x14QuotaControllerProtoP\x01ZJgoogle.golang.org/genproto/googleapis/api/servicecontrol/v1;servicecontrol\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_servicecontrol_dot_v1_dot_metric__value__pb2.DESCRIPTOR,])



_QUOTAOPERATION_QUOTAMODE = _descriptor.EnumDescriptor(
  name='QuotaMode',
  full_name='google.api.servicecontrol.v1.QuotaOperation.QuotaMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST_EFFORT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECK_ONLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=661,
  serialized_end=734,
)
_sym_db.RegisterEnumDescriptor(_QUOTAOPERATION_QUOTAMODE)

_QUOTAERROR_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='google.api.servicecontrol.v1.QuotaError.Code',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE_EXHAUSTED', index=1, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BILLING_NOT_ACTIVE', index=2, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROJECT_DELETED', index=3, number=108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API_KEY_INVALID', index=4, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='API_KEY_EXPIRED', index=5, number=112,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1062,
  serialized_end=1196,
)
_sym_db.RegisterEnumDescriptor(_QUOTAERROR_CODE)


_ALLOCATEQUOTAREQUEST = _descriptor.Descriptor(
  name='AllocateQuotaRequest',
  full_name='google.api.servicecontrol.v1.AllocateQuotaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='google.api.servicecontrol.v1.AllocateQuotaRequest.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocate_operation', full_name='google.api.servicecontrol.v1.AllocateQuotaRequest.allocate_operation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_config_id', full_name='google.api.servicecontrol.v1.AllocateQuotaRequest.service_config_id', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=165,
  serialized_end=310,
)


_QUOTAOPERATION_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='google.api.servicecontrol.v1.QuotaOperation.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='google.api.servicecontrol.v1.QuotaOperation.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='google.api.servicecontrol.v1.QuotaOperation.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=659,
)

_QUOTAOPERATION = _descriptor.Descriptor(
  name='QuotaOperation',
  full_name='google.api.servicecontrol.v1.QuotaOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='google.api.servicecontrol.v1.QuotaOperation.operation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method_name', full_name='google.api.servicecontrol.v1.QuotaOperation.method_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consumer_id', full_name='google.api.servicecontrol.v1.QuotaOperation.consumer_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='google.api.servicecontrol.v1.QuotaOperation.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quota_metrics', full_name='google.api.servicecontrol.v1.QuotaOperation.quota_metrics', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quota_mode', full_name='google.api.servicecontrol.v1.QuotaOperation.quota_mode', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUOTAOPERATION_LABELSENTRY, ],
  enum_types=[
    _QUOTAOPERATION_QUOTAMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=313,
  serialized_end=734,
)


_ALLOCATEQUOTARESPONSE = _descriptor.Descriptor(
  name='AllocateQuotaResponse',
  full_name='google.api.servicecontrol.v1.AllocateQuotaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='google.api.servicecontrol.v1.AllocateQuotaResponse.operation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocate_errors', full_name='google.api.servicecontrol.v1.AllocateQuotaResponse.allocate_errors', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quota_metrics', full_name='google.api.servicecontrol.v1.AllocateQuotaResponse.quota_metrics', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_config_id', full_name='google.api.servicecontrol.v1.AllocateQuotaResponse.service_config_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=737,
  serialized_end=945,
)


_QUOTAERROR = _descriptor.Descriptor(
  name='QuotaError',
  full_name='google.api.servicecontrol.v1.QuotaError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='google.api.servicecontrol.v1.QuotaError.code', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject', full_name='google.api.servicecontrol.v1.QuotaError.subject', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.api.servicecontrol.v1.QuotaError.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _QUOTAERROR_CODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1196,
)

_ALLOCATEQUOTAREQUEST.fields_by_name['allocate_operation'].message_type = _QUOTAOPERATION
_QUOTAOPERATION_LABELSENTRY.containing_type = _QUOTAOPERATION
_QUOTAOPERATION.fields_by_name['labels'].message_type = _QUOTAOPERATION_LABELSENTRY
_QUOTAOPERATION.fields_by_name['quota_metrics'].message_type = google_dot_api_dot_servicecontrol_dot_v1_dot_metric__value__pb2._METRICVALUESET
_QUOTAOPERATION.fields_by_name['quota_mode'].enum_type = _QUOTAOPERATION_QUOTAMODE
_QUOTAOPERATION_QUOTAMODE.containing_type = _QUOTAOPERATION
_ALLOCATEQUOTARESPONSE.fields_by_name['allocate_errors'].message_type = _QUOTAERROR
_ALLOCATEQUOTARESPONSE.fields_by_name['quota_metrics'].message_type = google_dot_api_dot_servicecontrol_dot_v1_dot_metric__value__pb2._METRICVALUESET
_QUOTAERROR.fields_by_name['code'].enum_type = _QUOTAERROR_CODE
_QUOTAERROR_CODE.containing_type = _QUOTAERROR
DESCRIPTOR.message_types_by_name['AllocateQuotaRequest'] = _ALLOCATEQUOTAREQUEST
DESCRIPTOR.message_types_by_name['QuotaOperation'] = _QUOTAOPERATION
DESCRIPTOR.message_types_by_name['AllocateQuotaResponse'] = _ALLOCATEQUOTARESPONSE
DESCRIPTOR.message_types_by_name['QuotaError'] = _QUOTAERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AllocateQuotaRequest = _reflection.GeneratedProtocolMessageType('AllocateQuotaRequest', (_message.Message,), {
  'DESCRIPTOR' : _ALLOCATEQUOTAREQUEST,
  '__module__' : 'google.api.servicecontrol.v1.quota_controller_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.AllocateQuotaRequest)
  })
_sym_db.RegisterMessage(AllocateQuotaRequest)

QuotaOperation = _reflection.GeneratedProtocolMessageType('QuotaOperation', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _QUOTAOPERATION_LABELSENTRY,
    '__module__' : 'google.api.servicecontrol.v1.quota_controller_pb2'
    # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.QuotaOperation.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _QUOTAOPERATION,
  '__module__' : 'google.api.servicecontrol.v1.quota_controller_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.QuotaOperation)
  })
_sym_db.RegisterMessage(QuotaOperation)
_sym_db.RegisterMessage(QuotaOperation.LabelsEntry)

AllocateQuotaResponse = _reflection.GeneratedProtocolMessageType('AllocateQuotaResponse', (_message.Message,), {
  'DESCRIPTOR' : _ALLOCATEQUOTARESPONSE,
  '__module__' : 'google.api.servicecontrol.v1.quota_controller_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.AllocateQuotaResponse)
  })
_sym_db.RegisterMessage(AllocateQuotaResponse)

QuotaError = _reflection.GeneratedProtocolMessageType('QuotaError', (_message.Message,), {
  'DESCRIPTOR' : _QUOTAERROR,
  '__module__' : 'google.api.servicecontrol.v1.quota_controller_pb2'
  # @@protoc_insertion_point(class_scope:google.api.servicecontrol.v1.QuotaError)
  })
_sym_db.RegisterMessage(QuotaError)


DESCRIPTOR._options = None
_QUOTAOPERATION_LABELSENTRY._options = None

_QUOTACONTROLLER = _descriptor.ServiceDescriptor(
  name='QuotaController',
  full_name='google.api.servicecontrol.v1.QuotaController',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1199,
  serialized_end=1393,
  methods=[
  _descriptor.MethodDescriptor(
    name='AllocateQuota',
    full_name='google.api.servicecontrol.v1.QuotaController.AllocateQuota',
    index=0,
    containing_service=None,
    input_type=_ALLOCATEQUOTAREQUEST,
    output_type=_ALLOCATEQUOTARESPONSE,
    serialized_options=b'\202\323\344\223\002.\")/v1/services/{service_name}:allocateQuota:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUOTACONTROLLER)

DESCRIPTOR.services_by_name['QuotaController'] = _QUOTACONTROLLER

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/socket_option.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/socket_option.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\021SocketOptionProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(envoy/config/core/v3/socket_option.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xb0\x02\n\x0cSocketOption\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05level\x18\x02 \x01(\x03\x12\x0c\n\x04name\x18\x03 \x01(\x03\x12\x13\n\tint_value\x18\x04 \x01(\x03H\x00\x12\x13\n\tbuf_value\x18\x05 \x01(\x0cH\x00\x12G\n\x05state\x18\x06 \x01(\x0e\x32..envoy.config.core.v3.SocketOption.SocketStateB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\"F\n\x0bSocketState\x12\x11\n\rSTATE_PREBIND\x10\x00\x12\x0f\n\x0bSTATE_BOUND\x10\x01\x12\x13\n\x0fSTATE_LISTENING\x10\x02:%\x9a\xc5\x88\x1e \n\x1e\x65nvoy.api.v2.core.SocketOptionB\x0c\n\x05value\x12\x03\xf8\x42\x01\x42\x41\n\"io.envoyproxy.envoy.config.core.v3B\x11SocketOptionProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_SOCKETOPTION_SOCKETSTATE = _descriptor.EnumDescriptor(
  name='SocketState',
  full_name='envoy.config.core.v3.SocketOption.SocketState',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATE_PREBIND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_BOUND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATE_LISTENING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=339,
  serialized_end=409,
)
_sym_db.RegisterEnumDescriptor(_SOCKETOPTION_SOCKETSTATE)


_SOCKETOPTION = _descriptor.Descriptor(
  name='SocketOption',
  full_name='envoy.config.core.v3.SocketOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='envoy.config.core.v3.SocketOption.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='envoy.config.core.v3.SocketOption.level', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.core.v3.SocketOption.name', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='envoy.config.core.v3.SocketOption.int_value', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buf_value', full_name='envoy.config.core.v3.SocketOption.buf_value', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='envoy.config.core.v3.SocketOption.state', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SOCKETOPTION_SOCKETSTATE,
  ],
  serialized_options=b'\232\305\210\036 \n\036envoy.api.v2.core.SocketOption',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='envoy.config.core.v3.SocketOption.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=158,
  serialized_end=462,
)

_SOCKETOPTION.fields_by_name['state'].enum_type = _SOCKETOPTION_SOCKETSTATE
_SOCKETOPTION_SOCKETSTATE.containing_type = _SOCKETOPTION
_SOCKETOPTION.oneofs_by_name['value'].fields.append(
  _SOCKETOPTION.fields_by_name['int_value'])
_SOCKETOPTION.fields_by_name['int_value'].containing_oneof = _SOCKETOPTION.oneofs_by_name['value']
_SOCKETOPTION.oneofs_by_name['value'].fields.append(
  _SOCKETOPTION.fields_by_name['buf_value'])
_SOCKETOPTION.fields_by_name['buf_value'].containing_oneof = _SOCKETOPTION.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['SocketOption'] = _SOCKETOPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SocketOption = _reflection.GeneratedProtocolMessageType('SocketOption', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTION,
  '__module__' : 'envoy.config.core.v3.socket_option_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.SocketOption)
  })
_sym_db.RegisterMessage(SocketOption)


DESCRIPTOR._options = None
_SOCKETOPTION.oneofs_by_name['value']._options = None
_SOCKETOPTION.fields_by_name['state']._options = None
_SOCKETOPTION._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/bootstrap/v2/bootstrap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.auth import secret_pb2 as envoy_dot_api_dot_v2_dot_auth_dot_secret__pb2
from envoy.api.v2 import cluster_pb2 as envoy_dot_api_dot_v2_dot_cluster__pb2
from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import config_source_pb2 as envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2
from envoy.api.v2.core import event_service_config_pb2 as envoy_dot_api_dot_v2_dot_core_dot_event__service__config__pb2
from envoy.api.v2.core import socket_option_pb2 as envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
from envoy.api.v2 import listener_pb2 as envoy_dot_api_dot_v2_dot_listener__pb2
from envoy.config.metrics.v2 import stats_pb2 as envoy_dot_config_dot_metrics_dot_v2_dot_stats__pb2
from envoy.config.overload.v2alpha import overload_pb2 as envoy_dot_config_dot_overload_dot_v2alpha_dot_overload__pb2
from envoy.config.trace.v2 import http_tracer_pb2 as envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from envoy.annotations import deprecation_pb2 as envoy_dot_annotations_dot_deprecation__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/bootstrap/v2/bootstrap.proto',
  package='envoy.config.bootstrap.v2',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.config.bootstrap.v2B\016BootstrapProtoP\001\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)envoy/config/bootstrap/v2/bootstrap.proto\x12\x19\x65nvoy.config.bootstrap.v2\x1a\x1e\x65nvoy/api/v2/auth/secret.proto\x1a\x1a\x65nvoy/api/v2/cluster.proto\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a%envoy/api/v2/core/config_source.proto\x1a,envoy/api/v2/core/event_service_config.proto\x1a%envoy/api/v2/core/socket_option.proto\x1a\x1b\x65nvoy/api/v2/listener.proto\x1a#envoy/config/metrics/v2/stats.proto\x1a,envoy/config/overload/v2alpha/overload.proto\x1a\'envoy/config/trace/v2/http_tracer.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a#envoy/annotations/deprecation.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x80\x0b\n\tBootstrap\x12%\n\x04node\x18\x01 \x01(\x0b\x32\x17.envoy.api.v2.core.Node\x12N\n\x10static_resources\x18\x02 \x01(\x0b\x32\x34.envoy.config.bootstrap.v2.Bootstrap.StaticResources\x12P\n\x11\x64ynamic_resources\x18\x03 \x01(\x0b\x32\x35.envoy.config.bootstrap.v2.Bootstrap.DynamicResources\x12\x42\n\x0f\x63luster_manager\x18\x04 \x01(\x0b\x32).envoy.config.bootstrap.v2.ClusterManager\x12\x36\n\nhds_config\x18\x0e \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSource\x12\x12\n\nflags_path\x18\x05 \x01(\t\x12\x37\n\x0bstats_sinks\x18\x06 \x03(\x0b\x32\".envoy.config.metrics.v2.StatsSink\x12:\n\x0cstats_config\x18\r \x01(\x0b\x32$.envoy.config.metrics.v2.StatsConfig\x12J\n\x14stats_flush_interval\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationB\x11\xfa\x42\x0e\xaa\x01\x0b\x1a\x03\x08\xac\x02\x32\x04\x10\xc0\x84=\x12\x35\n\x08watchdog\x18\x08 \x01(\x0b\x32#.envoy.config.bootstrap.v2.Watchdog\x12/\n\x07tracing\x18\t \x01(\x0b\x32\x1e.envoy.config.trace.v2.Tracing\x12=\n\x07runtime\x18\x0b \x01(\x0b\x32\".envoy.config.bootstrap.v2.RuntimeB\x08\x18\x01\xb8\xee\xf2\xd2\x05\x01\x12\x42\n\x0flayered_runtime\x18\x11 \x01(\x0b\x32).envoy.config.bootstrap.v2.LayeredRuntime\x12/\n\x05\x61\x64min\x18\x0c \x01(\x0b\x32 .envoy.config.bootstrap.v2.Admin\x12H\n\x10overload_manager\x18\x0f \x01(\x0b\x32..envoy.config.overload.v2alpha.OverloadManager\x12\x1f\n\x17\x65nable_dispatcher_stats\x18\x10 \x01(\x08\x12\x15\n\rheader_prefix\x18\x12 \x01(\t\x12\x43\n\x1dstats_server_version_override\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12\x1f\n\x17use_tcp_for_dns_lookups\x18\x14 \x01(\x08\x1a\x91\x01\n\x0fStaticResources\x12)\n\tlisteners\x18\x01 \x03(\x0b\x32\x16.envoy.api.v2.Listener\x12\'\n\x08\x63lusters\x18\x02 \x03(\x0b\x32\x15.envoy.api.v2.Cluster\x12*\n\x07secrets\x18\x03 \x03(\x0b\x32\x19.envoy.api.v2.auth.Secret\x1a\xba\x01\n\x10\x44ynamicResources\x12\x33\n\nlds_config\x18\x01 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\x12\x33\n\ncds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSource\x12\x36\n\nads_config\x18\x03 \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSourceJ\x04\x08\x04\x10\x05J\x04\x08\n\x10\x0b\"\x9c\x01\n\x05\x41\x64min\x12\x17\n\x0f\x61\x63\x63\x65ss_log_path\x18\x01 \x01(\t\x12\x14\n\x0cprofile_path\x18\x02 \x01(\t\x12+\n\x07\x61\x64\x64ress\x18\x03 \x01(\x0b\x32\x1a.envoy.api.v2.core.Address\x12\x37\n\x0esocket_options\x18\x04 \x03(\x0b\x32\x1f.envoy.api.v2.core.SocketOption\"\xe9\x02\n\x0e\x43lusterManager\x12\x1a\n\x12local_cluster_name\x18\x01 \x01(\t\x12U\n\x11outlier_detection\x18\x02 \x01(\x0b\x32:.envoy.config.bootstrap.v2.ClusterManager.OutlierDetection\x12;\n\x14upstream_bind_config\x18\x03 \x01(\x0b\x32\x1d.envoy.api.v2.core.BindConfig\x12=\n\x11load_stats_config\x18\x04 \x01(\x0b\x32\".envoy.api.v2.core.ApiConfigSource\x1ah\n\x10OutlierDetection\x12\x16\n\x0e\x65vent_log_path\x18\x01 \x01(\t\x12<\n\revent_service\x18\x02 \x01(\x0b\x32%.envoy.api.v2.core.EventServiceConfig\"\xd7\x01\n\x08Watchdog\x12/\n\x0cmiss_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x33\n\x10megamiss_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12/\n\x0ckill_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\x11multikill_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"{\n\x07Runtime\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x02 \x01(\t\x12\x1d\n\x15override_subdirectory\x18\x03 \x01(\t\x12%\n\x04\x62\x61se\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x83\x04\n\x0cRuntimeLayer\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12/\n\x0cstatic_layer\x18\x02 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12G\n\ndisk_layer\x18\x03 \x01(\x0b\x32\x31.envoy.config.bootstrap.v2.RuntimeLayer.DiskLayerH\x00\x12I\n\x0b\x61\x64min_layer\x18\x04 \x01(\x0b\x32\x32.envoy.config.bootstrap.v2.RuntimeLayer.AdminLayerH\x00\x12G\n\nrtds_layer\x18\x05 \x01(\x0b\x32\x31.envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayerH\x00\x1aW\n\tDiskLayer\x12\x14\n\x0csymlink_root\x18\x01 \x01(\t\x12\x14\n\x0csubdirectory\x18\x03 \x01(\t\x12\x1e\n\x16\x61ppend_service_cluster\x18\x02 \x01(\x08\x1a\x0c\n\nAdminLayer\x1aO\n\tRtdsLayer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x34\n\x0brtds_config\x18\x02 \x01(\x0b\x32\x1f.envoy.api.v2.core.ConfigSourceB\x16\n\x0flayer_specifier\x12\x03\xf8\x42\x01\"I\n\x0eLayeredRuntime\x12\x37\n\x06layers\x18\x01 \x03(\x0b\x32\'.envoy.config.bootstrap.v2.RuntimeLayerBC\n\'io.envoyproxy.envoy.config.bootstrap.v2B\x0e\x42ootstrapProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_auth_dot_secret__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_cluster__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_event__service__config__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_listener__pb2.DESCRIPTOR,envoy_dot_config_dot_metrics_dot_v2_dot_stats__pb2.DESCRIPTOR,envoy_dot_config_dot_overload_dot_v2alpha_dot_overload__pb2.DESCRIPTOR,envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,envoy_dot_annotations_dot_deprecation__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_BOOTSTRAP_STATICRESOURCES = _descriptor.Descriptor(
  name='StaticResources',
  full_name='envoy.config.bootstrap.v2.Bootstrap.StaticResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='listeners', full_name='envoy.config.bootstrap.v2.Bootstrap.StaticResources.listeners', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clusters', full_name='envoy.config.bootstrap.v2.Bootstrap.StaticResources.clusters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secrets', full_name='envoy.config.bootstrap.v2.Bootstrap.StaticResources.secrets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1728,
  serialized_end=1873,
)

_BOOTSTRAP_DYNAMICRESOURCES = _descriptor.Descriptor(
  name='DynamicResources',
  full_name='envoy.config.bootstrap.v2.Bootstrap.DynamicResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lds_config', full_name='envoy.config.bootstrap.v2.Bootstrap.DynamicResources.lds_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cds_config', full_name='envoy.config.bootstrap.v2.Bootstrap.DynamicResources.cds_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ads_config', full_name='envoy.config.bootstrap.v2.Bootstrap.DynamicResources.ads_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1876,
  serialized_end=2062,
)

_BOOTSTRAP = _descriptor.Descriptor(
  name='Bootstrap',
  full_name='envoy.config.bootstrap.v2.Bootstrap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='envoy.config.bootstrap.v2.Bootstrap.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_resources', full_name='envoy.config.bootstrap.v2.Bootstrap.static_resources', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dynamic_resources', full_name='envoy.config.bootstrap.v2.Bootstrap.dynamic_resources', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cluster_manager', full_name='envoy.config.bootstrap.v2.Bootstrap.cluster_manager', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hds_config', full_name='envoy.config.bootstrap.v2.Bootstrap.hds_config', index=4,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags_path', full_name='envoy.config.bootstrap.v2.Bootstrap.flags_path', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_sinks', full_name='envoy.config.bootstrap.v2.Bootstrap.stats_sinks', index=6,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_config', full_name='envoy.config.bootstrap.v2.Bootstrap.stats_config', index=7,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_flush_interval', full_name='envoy.config.bootstrap.v2.Bootstrap.stats_flush_interval', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\016\252\001\013\032\003\010\254\0022\004\020\300\204=', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='watchdog', full_name='envoy.config.bootstrap.v2.Bootstrap.watchdog', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tracing', full_name='envoy.config.bootstrap.v2.Bootstrap.tracing', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime', full_name='envoy.config.bootstrap.v2.Bootstrap.runtime', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001\270\356\362\322\005\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layered_runtime', full_name='envoy.config.bootstrap.v2.Bootstrap.layered_runtime', index=12,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin', full_name='envoy.config.bootstrap.v2.Bootstrap.admin', index=13,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overload_manager', full_name='envoy.config.bootstrap.v2.Bootstrap.overload_manager', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_dispatcher_stats', full_name='envoy.config.bootstrap.v2.Bootstrap.enable_dispatcher_stats', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header_prefix', full_name='envoy.config.bootstrap.v2.Bootstrap.header_prefix', index=16,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_server_version_override', full_name='envoy.config.bootstrap.v2.Bootstrap.stats_server_version_override', index=17,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_tcp_for_dns_lookups', full_name='envoy.config.bootstrap.v2.Bootstrap.use_tcp_for_dns_lookups', index=18,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BOOTSTRAP_STATICRESOURCES, _BOOTSTRAP_DYNAMICRESOURCES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=660,
  serialized_end=2068,
)


_ADMIN = _descriptor.Descriptor(
  name='Admin',
  full_name='envoy.config.bootstrap.v2.Admin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_log_path', full_name='envoy.config.bootstrap.v2.Admin.access_log_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile_path', full_name='envoy.config.bootstrap.v2.Admin.profile_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='envoy.config.bootstrap.v2.Admin.address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='socket_options', full_name='envoy.config.bootstrap.v2.Admin.socket_options', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2071,
  serialized_end=2227,
)


_CLUSTERMANAGER_OUTLIERDETECTION = _descriptor.Descriptor(
  name='OutlierDetection',
  full_name='envoy.config.bootstrap.v2.ClusterManager.OutlierDetection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_log_path', full_name='envoy.config.bootstrap.v2.ClusterManager.OutlierDetection.event_log_path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_service', full_name='envoy.config.bootstrap.v2.ClusterManager.OutlierDetection.event_service', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2487,
  serialized_end=2591,
)

_CLUSTERMANAGER = _descriptor.Descriptor(
  name='ClusterManager',
  full_name='envoy.config.bootstrap.v2.ClusterManager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='local_cluster_name', full_name='envoy.config.bootstrap.v2.ClusterManager.local_cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outlier_detection', full_name='envoy.config.bootstrap.v2.ClusterManager.outlier_detection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upstream_bind_config', full_name='envoy.config.bootstrap.v2.ClusterManager.upstream_bind_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='load_stats_config', full_name='envoy.config.bootstrap.v2.ClusterManager.load_stats_config', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERMANAGER_OUTLIERDETECTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2230,
  serialized_end=2591,
)


_WATCHDOG = _descriptor.Descriptor(
  name='Watchdog',
  full_name='envoy.config.bootstrap.v2.Watchdog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='miss_timeout', full_name='envoy.config.bootstrap.v2.Watchdog.miss_timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='megamiss_timeout', full_name='envoy.config.bootstrap.v2.Watchdog.megamiss_timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kill_timeout', full_name='envoy.config.bootstrap.v2.Watchdog.kill_timeout', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multikill_timeout', full_name='envoy.config.bootstrap.v2.Watchdog.multikill_timeout', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2594,
  serialized_end=2809,
)


_RUNTIME = _descriptor.Descriptor(
  name='Runtime',
  full_name='envoy.config.bootstrap.v2.Runtime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symlink_root', full_name='envoy.config.bootstrap.v2.Runtime.symlink_root', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subdirectory', full_name='envoy.config.bootstrap.v2.Runtime.subdirectory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_subdirectory', full_name='envoy.config.bootstrap.v2.Runtime.override_subdirectory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base', full_name='envoy.config.bootstrap.v2.Runtime.base', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2811,
  serialized_end=2934,
)


_RUNTIMELAYER_DISKLAYER = _descriptor.Descriptor(
  name='DiskLayer',
  full_name='envoy.config.bootstrap.v2.RuntimeLayer.DiskLayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='symlink_root', full_name='envoy.config.bootstrap.v2.RuntimeLayer.DiskLayer.symlink_root', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subdirectory', full_name='envoy.config.bootstrap.v2.RuntimeLayer.DiskLayer.subdirectory', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='append_service_cluster', full_name='envoy.config.bootstrap.v2.RuntimeLayer.DiskLayer.append_service_cluster', index=2,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3246,
  serialized_end=3333,
)

_RUNTIMELAYER_ADMINLAYER = _descriptor.Descriptor(
  name='AdminLayer',
  full_name='envoy.config.bootstrap.v2.RuntimeLayer.AdminLayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3335,
  serialized_end=3347,
)

_RUNTIMELAYER_RTDSLAYER = _descriptor.Descriptor(
  name='RtdsLayer',
  full_name='envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayer.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtds_config', full_name='envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayer.rtds_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3349,
  serialized_end=3428,
)

_RUNTIMELAYER = _descriptor.Descriptor(
  name='RuntimeLayer',
  full_name='envoy.config.bootstrap.v2.RuntimeLayer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.bootstrap.v2.RuntimeLayer.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='static_layer', full_name='envoy.config.bootstrap.v2.RuntimeLayer.static_layer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_layer', full_name='envoy.config.bootstrap.v2.RuntimeLayer.disk_layer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='admin_layer', full_name='envoy.config.bootstrap.v2.RuntimeLayer.admin_layer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtds_layer', full_name='envoy.config.bootstrap.v2.RuntimeLayer.rtds_layer', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RUNTIMELAYER_DISKLAYER, _RUNTIMELAYER_ADMINLAYER, _RUNTIMELAYER_RTDSLAYER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='layer_specifier', full_name='envoy.config.bootstrap.v2.RuntimeLayer.layer_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2937,
  serialized_end=3452,
)


_LAYEREDRUNTIME = _descriptor.Descriptor(
  name='LayeredRuntime',
  full_name='envoy.config.bootstrap.v2.LayeredRuntime',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='layers', full_name='envoy.config.bootstrap.v2.LayeredRuntime.layers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3454,
  serialized_end=3527,
)

_BOOTSTRAP_STATICRESOURCES.fields_by_name['listeners'].message_type = envoy_dot_api_dot_v2_dot_listener__pb2._LISTENER
_BOOTSTRAP_STATICRESOURCES.fields_by_name['clusters'].message_type = envoy_dot_api_dot_v2_dot_cluster__pb2._CLUSTER
_BOOTSTRAP_STATICRESOURCES.fields_by_name['secrets'].message_type = envoy_dot_api_dot_v2_dot_auth_dot_secret__pb2._SECRET
_BOOTSTRAP_STATICRESOURCES.containing_type = _BOOTSTRAP
_BOOTSTRAP_DYNAMICRESOURCES.fields_by_name['lds_config'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._CONFIGSOURCE
_BOOTSTRAP_DYNAMICRESOURCES.fields_by_name['cds_config'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._CONFIGSOURCE
_BOOTSTRAP_DYNAMICRESOURCES.fields_by_name['ads_config'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._APICONFIGSOURCE
_BOOTSTRAP_DYNAMICRESOURCES.containing_type = _BOOTSTRAP
_BOOTSTRAP.fields_by_name['node'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._NODE
_BOOTSTRAP.fields_by_name['static_resources'].message_type = _BOOTSTRAP_STATICRESOURCES
_BOOTSTRAP.fields_by_name['dynamic_resources'].message_type = _BOOTSTRAP_DYNAMICRESOURCES
_BOOTSTRAP.fields_by_name['cluster_manager'].message_type = _CLUSTERMANAGER
_BOOTSTRAP.fields_by_name['hds_config'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._APICONFIGSOURCE
_BOOTSTRAP.fields_by_name['stats_sinks'].message_type = envoy_dot_config_dot_metrics_dot_v2_dot_stats__pb2._STATSSINK
_BOOTSTRAP.fields_by_name['stats_config'].message_type = envoy_dot_config_dot_metrics_dot_v2_dot_stats__pb2._STATSCONFIG
_BOOTSTRAP.fields_by_name['stats_flush_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_BOOTSTRAP.fields_by_name['watchdog'].message_type = _WATCHDOG
_BOOTSTRAP.fields_by_name['tracing'].message_type = envoy_dot_config_dot_trace_dot_v2_dot_http__tracer__pb2._TRACING
_BOOTSTRAP.fields_by_name['runtime'].message_type = _RUNTIME
_BOOTSTRAP.fields_by_name['layered_runtime'].message_type = _LAYEREDRUNTIME
_BOOTSTRAP.fields_by_name['admin'].message_type = _ADMIN
_BOOTSTRAP.fields_by_name['overload_manager'].message_type = envoy_dot_config_dot_overload_dot_v2alpha_dot_overload__pb2._OVERLOADMANAGER
_BOOTSTRAP.fields_by_name['stats_server_version_override'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_ADMIN.fields_by_name['address'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._ADDRESS
_ADMIN.fields_by_name['socket_options'].message_type = envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2._SOCKETOPTION
_CLUSTERMANAGER_OUTLIERDETECTION.fields_by_name['event_service'].message_type = envoy_dot_api_dot_v2_dot_core_dot_event__service__config__pb2._EVENTSERVICECONFIG
_CLUSTERMANAGER_OUTLIERDETECTION.containing_type = _CLUSTERMANAGER
_CLUSTERMANAGER.fields_by_name['outlier_detection'].message_type = _CLUSTERMANAGER_OUTLIERDETECTION
_CLUSTERMANAGER.fields_by_name['upstream_bind_config'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._BINDCONFIG
_CLUSTERMANAGER.fields_by_name['load_stats_config'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._APICONFIGSOURCE
_WATCHDOG.fields_by_name['miss_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WATCHDOG.fields_by_name['megamiss_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WATCHDOG.fields_by_name['kill_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WATCHDOG.fields_by_name['multikill_timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RUNTIME.fields_by_name['base'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RUNTIMELAYER_DISKLAYER.containing_type = _RUNTIMELAYER
_RUNTIMELAYER_ADMINLAYER.containing_type = _RUNTIMELAYER
_RUNTIMELAYER_RTDSLAYER.fields_by_name['rtds_config'].message_type = envoy_dot_api_dot_v2_dot_core_dot_config__source__pb2._CONFIGSOURCE
_RUNTIMELAYER_RTDSLAYER.containing_type = _RUNTIMELAYER
_RUNTIMELAYER.fields_by_name['static_layer'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_RUNTIMELAYER.fields_by_name['disk_layer'].message_type = _RUNTIMELAYER_DISKLAYER
_RUNTIMELAYER.fields_by_name['admin_layer'].message_type = _RUNTIMELAYER_ADMINLAYER
_RUNTIMELAYER.fields_by_name['rtds_layer'].message_type = _RUNTIMELAYER_RTDSLAYER
_RUNTIMELAYER.oneofs_by_name['layer_specifier'].fields.append(
  _RUNTIMELAYER.fields_by_name['static_layer'])
_RUNTIMELAYER.fields_by_name['static_layer'].containing_oneof = _RUNTIMELAYER.oneofs_by_name['layer_specifier']
_RUNTIMELAYER.oneofs_by_name['layer_specifier'].fields.append(
  _RUNTIMELAYER.fields_by_name['disk_layer'])
_RUNTIMELAYER.fields_by_name['disk_layer'].containing_oneof = _RUNTIMELAYER.oneofs_by_name['layer_specifier']
_RUNTIMELAYER.oneofs_by_name['layer_specifier'].fields.append(
  _RUNTIMELAYER.fields_by_name['admin_layer'])
_RUNTIMELAYER.fields_by_name['admin_layer'].containing_oneof = _RUNTIMELAYER.oneofs_by_name['layer_specifier']
_RUNTIMELAYER.oneofs_by_name['layer_specifier'].fields.append(
  _RUNTIMELAYER.fields_by_name['rtds_layer'])
_RUNTIMELAYER.fields_by_name['rtds_layer'].containing_oneof = _RUNTIMELAYER.oneofs_by_name['layer_specifier']
_LAYEREDRUNTIME.fields_by_name['layers'].message_type = _RUNTIMELAYER
DESCRIPTOR.message_types_by_name['Bootstrap'] = _BOOTSTRAP
DESCRIPTOR.message_types_by_name['Admin'] = _ADMIN
DESCRIPTOR.message_types_by_name['ClusterManager'] = _CLUSTERMANAGER
DESCRIPTOR.message_types_by_name['Watchdog'] = _WATCHDOG
DESCRIPTOR.message_types_by_name['Runtime'] = _RUNTIME
DESCRIPTOR.message_types_by_name['RuntimeLayer'] = _RUNTIMELAYER
DESCRIPTOR.message_types_by_name['LayeredRuntime'] = _LAYEREDRUNTIME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Bootstrap = _reflection.GeneratedProtocolMessageType('Bootstrap', (_message.Message,), {

  'StaticResources' : _reflection.GeneratedProtocolMessageType('StaticResources', (_message.Message,), {
    'DESCRIPTOR' : _BOOTSTRAP_STATICRESOURCES,
    '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.Bootstrap.StaticResources)
    })
  ,

  'DynamicResources' : _reflection.GeneratedProtocolMessageType('DynamicResources', (_message.Message,), {
    'DESCRIPTOR' : _BOOTSTRAP_DYNAMICRESOURCES,
    '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.Bootstrap.DynamicResources)
    })
  ,
  'DESCRIPTOR' : _BOOTSTRAP,
  '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.Bootstrap)
  })
_sym_db.RegisterMessage(Bootstrap)
_sym_db.RegisterMessage(Bootstrap.StaticResources)
_sym_db.RegisterMessage(Bootstrap.DynamicResources)

Admin = _reflection.GeneratedProtocolMessageType('Admin', (_message.Message,), {
  'DESCRIPTOR' : _ADMIN,
  '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.Admin)
  })
_sym_db.RegisterMessage(Admin)

ClusterManager = _reflection.GeneratedProtocolMessageType('ClusterManager', (_message.Message,), {

  'OutlierDetection' : _reflection.GeneratedProtocolMessageType('OutlierDetection', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERMANAGER_OUTLIERDETECTION,
    '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.ClusterManager.OutlierDetection)
    })
  ,
  'DESCRIPTOR' : _CLUSTERMANAGER,
  '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.ClusterManager)
  })
_sym_db.RegisterMessage(ClusterManager)
_sym_db.RegisterMessage(ClusterManager.OutlierDetection)

Watchdog = _reflection.GeneratedProtocolMessageType('Watchdog', (_message.Message,), {
  'DESCRIPTOR' : _WATCHDOG,
  '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.Watchdog)
  })
_sym_db.RegisterMessage(Watchdog)

Runtime = _reflection.GeneratedProtocolMessageType('Runtime', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIME,
  '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.Runtime)
  })
_sym_db.RegisterMessage(Runtime)

RuntimeLayer = _reflection.GeneratedProtocolMessageType('RuntimeLayer', (_message.Message,), {

  'DiskLayer' : _reflection.GeneratedProtocolMessageType('DiskLayer', (_message.Message,), {
    'DESCRIPTOR' : _RUNTIMELAYER_DISKLAYER,
    '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.RuntimeLayer.DiskLayer)
    })
  ,

  'AdminLayer' : _reflection.GeneratedProtocolMessageType('AdminLayer', (_message.Message,), {
    'DESCRIPTOR' : _RUNTIMELAYER_ADMINLAYER,
    '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.RuntimeLayer.AdminLayer)
    })
  ,

  'RtdsLayer' : _reflection.GeneratedProtocolMessageType('RtdsLayer', (_message.Message,), {
    'DESCRIPTOR' : _RUNTIMELAYER_RTDSLAYER,
    '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.RuntimeLayer.RtdsLayer)
    })
  ,
  'DESCRIPTOR' : _RUNTIMELAYER,
  '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.RuntimeLayer)
  })
_sym_db.RegisterMessage(RuntimeLayer)
_sym_db.RegisterMessage(RuntimeLayer.DiskLayer)
_sym_db.RegisterMessage(RuntimeLayer.AdminLayer)
_sym_db.RegisterMessage(RuntimeLayer.RtdsLayer)

LayeredRuntime = _reflection.GeneratedProtocolMessageType('LayeredRuntime', (_message.Message,), {
  'DESCRIPTOR' : _LAYEREDRUNTIME,
  '__module__' : 'envoy.config.bootstrap.v2.bootstrap_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.bootstrap.v2.LayeredRuntime)
  })
_sym_db.RegisterMessage(LayeredRuntime)


DESCRIPTOR._options = None
_BOOTSTRAP.fields_by_name['stats_flush_interval']._options = None
_BOOTSTRAP.fields_by_name['runtime']._options = None
_RUNTIMELAYER.oneofs_by_name['layer_specifier']._options = None
_RUNTIMELAYER.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
